@@ -34,10 +34,12 @@ public:
 
     void add(SoundFile *file);
     const QList<SoundFile *> *getList();
+    void move(int from, int to);
     void remove(SoundFile *file);
 
 signals:
     void changed();
+    void moved(int to);
 
 public slots:
     void save();
